@@ -1,10 +1,20 @@
 from rest_framework import serializers, viewsets
 from rest_framework_yaml.parsers import YAMLParser
 from rest_framework_yaml.renderers import YAMLRenderer
-from .models import Application, Federation, ApplicationComponent
+from .models import Application, Federation
 from djangoldp_component.models import Component, Package
 
 
+def format(value):
+    match value.lower():
+        case "false":
+            return False
+        case "true":
+            return True
+        case _:
+            return value
+
+
 class ApplicationSerializer(serializers.HyperlinkedModelSerializer):
     class Meta:
         model = Application
@@ -40,28 +50,29 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
 
         for applicationComponent in application["components"]:
             component = Component.objects.get(id=applicationComponent.obj.component_id)
-            insertComponent = {"type": component.name, "parameters": []}
+            insertComponent = {"type": component.name, "route": False, "parameters": []}
             keys = []
             for parameter in applicationComponent.obj.parameters.all():
-                insertComponent["parameters"].append(
-                    {
-                        "key": parameter.key,
-                        "value": parameter.value,
-                    }
-                )
+                if parameter.key == "route":
+                    insertComponent["route"] = format(parameter.value)
+                else:
+                    i = {}
+                    i[parameter.key] = format(parameter.value)
+                    insertComponent["parameters"].append(i)
                 keys.append(parameter.key)
             for parameter in component.parameters.all():
                 if not parameter.key in keys:
-                    insertComponent["parameters"].append(
-                        {
-                            "key": parameter.key,
-                            "value": parameter.default,
-                        }
-                    )
+                    if parameter.key == "route":
+                        insertComponent["route"] = format(parameter.default)
+                    else:
+                        i = {}
+                        i[parameter.key] = format(parameter.default)
+                        insertComponent["parameters"].append(i)
             serialized["apps"]["hosts"][application["slug"]]["components"].append(
                 insertComponent
             )
 
+        insertDependencies = []
         for applicationPackage in application["packages"]:
             package = Package.objects.get(id=applicationPackage.obj.package_id)
             insertDependency = {
@@ -71,24 +82,20 @@ class ApplicationDetailSerializer(serializers.HyperlinkedModelSerializer):
             }
             keys = []
             for parameter in applicationPackage.obj.parameters.all():
-                insertDependency["parameters"].append(
-                    {
-                        "key": parameter.key,
-                        "value": parameter.value,
-                    }
-                )
-                keys.append(parameter.key)
+                if not parameter.key in keys:
+                    i = {}
+                    i[parameter.key] = format(parameter.value)
+                    insertDependency["parameters"].append(i)
+                    keys.append(parameter.key)
             for parameter in package.parameters.all():
                 if not parameter.key in keys:
-                    insertDependency["parameters"].append(
-                        {
-                            "key": parameter.key,
-                            "value": parameter.default,
-                        }
-                    )
-            serialized["apps"]["hosts"][application["slug"]]["packages"].append(
-                insertDependency
-            )
+                    i = {}
+                    i[parameter.key] = format(parameter.default)
+                    insertDependency["parameters"].append(i)
+            insertDependencies.append(insertDependency)
+        serialized["apps"]["hosts"][application["slug"]][
+            "packages"
+        ] = insertDependencies
 
         return serialized
 
